#!/bin/sh -x
#
# When we upgrade from Framework 3.6 to the 3.6.1, 3.6.2, or 3.6.3
# maintenance releases, some or all of the ManagedNode, Gateway,
# ProfileManager, and Endpoint extended inheritance is removed.
# Applications may have extended these classes during installation
# using winstendpt or oi_add commands.   
#
# Thus, if a Framework maintence release is installed after installing
# an application which extends these objects, those extensions can be
# lost and the application can get NO_METHOD errors when run. This
# script will restore those extended objects.
#

CLO=`wlookup Library`
LIB='TMF_SysAdmin::Library::lookup_impl'

afunc()
{
	extended_CO=`idlcall $CLO $LIB '"'$1'"'`
	Res_CO=`wlookup -r Classes $2`
	winstendpt $extended_CO $Res_CO > /dev/null 2>&1 
}

#
# At the time this script was generated, the only application that was
# experiencing this problem was Inventory. The Inventory application has
# two classes of behavior objects which extended Framework resources, the
# Gateway and the ProfileManager.
#
# This script is written to restore those two Inventory behavior objects,
# but can be modified to include additional applications that experience
# similar problems.  If it is necessary to modify this script, please
# add your application class name to the first line of the "for loop"
# and also to the "case statement" clauses.  The function afunc() should
# be called with the appropriate Resource Object name for your
# application.
#

#
# For each application class that has been affected, get the behavior
# object label and pass the name of the framework resource that needs to
# be extended to afunc(). If there are multiple framework resources 
# for a single application class, afunc() can be called multiple times. 
#
for i in MCollect InventoryProfileEndpoint
do
	CO=`wlookup -r Classes $i`
	BO=`objcall $CO _get_behavior`
	BO_label=`idlattr -tg $BO label Object | awk -F. '{print $1}'`
	case $i in
		MCollect)	
			afunc $BO_label Gateway
			;;
		InventoryProfileEndpoint)	
			afunc $BO_label ProfileManager
			;;
		*)	print "error: check for correct application name."
			exit 1 
			;;
	esac
done
exit 0

